/*
 *  Copyright (C) 2000 Lyrisoft Solutions, Inc.
 *
 *  This library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Library General Public License as published
 *  by the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package com.lyrisoft.sql;

import java.sql.*;
import java.util.Vector;

/**
 * Convenient SQL methods.
 *
 * @author Taso Lyristis (taso@lyrisoft.com)
 * @version $Revision: 1.1 $
 */
public class Util {
    /**
     * Puts string in single quotes, and escapes all the quotes in the String,
     * making it suitable for a database query.
     * @param input the input string
     * @return the string property quoted, or a string that contains the word "null"
     *         if the input was null
     */
    public static final String quote(String input) {
        if (input == null || input.length() == 0) {
            return null;
        }
        StringBuffer sb = new StringBuffer();
        char[] chars = input.toCharArray();
        sb.append("'");
        for (int i=0; i < chars.length; i++) {
            sb.append(chars[i]);
            if (chars[i] == '\'') {
                sb.append("\'");
            }
        }
        sb.append("'");
        return sb.toString();
    }

    public static final String clob2String(Clob c) throws SQLException {
        if (c == null) {
            return null;
        } else if (c.length() == 0) {
            return "";
        } else {
            return c.getSubString(1, (int)c.length());
        }
    }

    // NOTE: This might only work on Oracle
    public static final String toSqlDate(java.util.Date d) {
        return "TO_DATE('" + new java.sql.Date(d.getTime()) + " "
               + new java.sql.Time(d.getTime()) + "', 'YYYY-MM-DD HH24:MI:SS')";
    }
}
